@@ -112,7 +112,7 @@ class StringValueToken(ExpressionToken):
     value: str
 
     def to_sql(self, dialect: Dialect) -> str:
-        return escape_raw_sql(quote_string(self.value))
+        return escape_raw_sql(quote_string(dialect, self.value))
 
 
 @dataclass(frozen=True)
@@ -307,6 +307,12 @@ class Expression:
             isinstance(token, TableColumnReferenceToken) for token in self.get_all_tokens()
         )
 
+    @property
+    def has_multi_level_expressions(self) -> bool:
+        return isinstance(self, MultiLevelExpression) or any(
+            d.has_multi_level_expressions for d in self.data if isinstance(d, Expression)
+        )
+
     def resolve_column_references(self, dialect: Dialect, table_name: Optional[str]) -> 'Expression':
         """ resolve the table name aliases for all columns in this expression """
         result: List[Union[ExpressionToken, Expression]] = []
@@ -448,7 +454,20 @@ class WindowFunctionExpression(Expression):
         return False
 
 
-def join_expressions(expressions: List[Expression], join_str: str = ', ') -> Expression:
+class MultiLevelExpression(Expression):
+    """
+    A MultiLevelExpression contains multiple expressions referencing to different columns.
+    """
+    def to_sql(self, dialect: Dialect, table_name: Optional[str] = None) -> str:
+        # same as original function, we just need to join by a comma since parent expression is composed
+        # by multiple column references
+        resolved_tables_expression = self.resolve_column_references(dialect, table_name)
+        return ','.join(
+            d.to_sql(dialect=dialect) for d in resolved_tables_expression.data
+        )
+
+
+def join_expressions(expressions: Sequence[Expression], join_str: str = ', ') -> Expression:
     """
     Construct an expression consisting of the given list of expressions joined by the join_str.
     """
