@@ -2,11 +2,10 @@
 Copyright 2021 Objectiv B.V.
 """
 from bach.series.series import Series, value_to_series
-from bach.series.series_numeric import \
-    SeriesAbstractNumeric, SeriesInt64, SeriesFloat64
+from bach.series.series_numeric import SeriesAbstractNumeric, SeriesInt64, SeriesFloat64
 from bach.series.series_boolean import SeriesBoolean
 from bach.series.series_uuid import SeriesUuid
-from bach.series.series_json import SeriesJson, SeriesJsonb
+from bach.series.series_json import SeriesJson, SeriesJsonPostgres
 from bach.series.series_string import SeriesString
 from bach.series.series_datetime import \
     SeriesAbstractDateTime, SeriesDate, SeriesTime, SeriesTimestamp, SeriesTimedelta
